@@ -1,6 +1,6 @@
 #' Fit the radiological search model (RSM) to an ROC dataset
 #' 
-#' @description Fit an RSM-predicted ROC curve to a \strong{binned single-modality single-treatment ROC dataset}
+#' @description Fit an RSM-predicted ROC curve to a \strong{binned single-treatment single-reader ROC dataset}
 #' 
 #' @param binnedRocData The \strong{binned ROC} dataset containing the data
 #' @param lesDistr The lesion distribution 1D array. 
@@ -45,41 +45,41 @@
 #' @examples
 #' \donttest{
 #' ## Test with included ROC data (some bins have zero counts)
-#' lesDistr <- UtilLesionDistr(dataset02)
-#' retFit <- FitRsmRoc(dataset02, lesDistr[,2])
+#' lesDistr <- UtilLesionDistrVector(dataset02)
+#' retFit <- FitRsmRoc(dataset02, lesDistr)
 #' ## print(retFit$fittedPlot)
 #' 
 #' ## Test with included degenerate ROC data
-#' lesDistr <- UtilLesionDistr(datasetDegenerate)
-#' retFit <- FitRsmRoc(datasetDegenerate, lesDistr[,2])
+#' lesDistr <- UtilLesionDistrVector(datasetDegenerate)
+#' retFit <- FitRsmRoc(datasetDegenerate, lesDistr)
 #' 
 #' ## Test with single interior point data
 #' fp <- c(rep(1,7), rep(2, 3))
 #' tp <- c(rep(1,5), rep(2, 5))
 #' binnedRocData <- Df2RJafrocDataset(fp, tp)
-#' lesDistr <- UtilLesionDistr(binnedRocData)
-#' retFit <- FitRsmRoc(binnedRocData, lesDistr[,2])
+#' lesDistr <- UtilLesionDistrVector(binnedRocData)
+#' retFit <- FitRsmRoc(binnedRocData, lesDistr)
 #' 
 #' ## Test with two interior data points
 #' fp <- c(rep(1,7), rep(2, 5), rep(3, 3))
 #' tp <- c(rep(1,3), rep(2, 5), rep(3, 7))
 #' binnedRocData <- Df2RJafrocDataset(fp, tp)
-#' lesDistr <- UtilLesionDistr(binnedRocData)
-#' retFit <- FitRsmRoc(binnedRocData, lesDistr[,2])
+#' lesDistr <- UtilLesionDistrVector(binnedRocData)
+#' retFit <- FitRsmRoc(binnedRocData, lesDistr)
 #' 
 #' 
 #' ## Test with three interior data points
 #' fp <- c(rep(1,12), rep(2, 5), rep(3, 3), rep(4, 5)) #25
 #' tp <- c(rep(1,3), rep(2, 5), rep(3, 7), rep(4, 10)) #25
 #' binnedRocData <- Df2RJafrocDataset(fp, tp)
-#' lesDistr <- UtilLesionDistr(binnedRocData)
-#' retFit <- FitRsmRoc(binnedRocData, lesDistr[,2])
+#' lesDistr <- UtilLesionDistrVector(binnedRocData)
+#' retFit <- FitRsmRoc(binnedRocData, lesDistr)
 #' 
 #' ## test for TONY data, i = 2 and j = 3 
 #' ## only case permitting chisqure calculation
-#' lesDistr <- UtilLesionDistr(dataset01)
+#' lesDistr <- UtilLesionDistrVector(dataset01)
 #' rocData <- DfFroc2Roc(dataset01)
-#' retFit <- FitRsmRoc(rocData, lesDistr[,2], trt = 2, rdr = 3)
+#' retFit <- FitRsmRoc(rocData, lesDistr, trt = 2, rdr = 3)
 #' ## print(retFit$fittedPlot)
 #' retFit$ChisqrFitStats
 #' }
@@ -92,6 +92,7 @@
 #'
 #' Chakraborty DP (2017) \emph{Observer Performance Methods for Diagnostic Imaging - Foundations, 
 #' Modeling, and Applications with R-Based Examples}, CRC Press, Boca Raton, FL. 
+#' \url{https://www.routledge.com/Observer-Performance-Methods-for-Diagnostic-Imaging-Foundations-Modeling/Chakraborty/p/book/9781482214840}
 #' 
 #'  
 #' @importFrom bbmle mle2
@@ -120,7 +121,8 @@ FitRsmRoc <- function(binnedRocData, lesDistr, trt = 1, rdr = 1){
   minMu <- RJafrocEnv$minMu
   class(lesDistr) <- "numeric"
   
-  lesDistr <- UtilLesionDistr(lesDistr) # convert to internal 2D form
+  # following line no longer needed as lesDist is now a 1D vector
+  #lesDistr <- UtilLesionDistrVector(lesDistr) # convert to internal 2D form
   
   fp <- binnedRocData$ratings$NL[trt,rdr,,1];fp <- fp[fp != -Inf]
   tp <- binnedRocData$ratings$LL[trt,rdr,,1]
@@ -223,7 +225,7 @@ FitRsmRoc <- function(binnedRocData, lesDistr, trt = 1, rdr = 1){
   
   NLLFin <- ret@min
   
-  AUC <- UtilAnalyticalAucsRSM(mu, lambda, nu, zeta1 <- -Inf, lesDistr[,2])$aucROC # 11/30/20
+  AUC <- UtilAnalyticalAucsRSM(mu, lambdaP, nuP, zeta1 <- -Inf, lesDistr)$aucROC # 11/30/20
   ## following checks out
   ##temp <- tempAucRSM (c(ret@coef[1], ret@coef[2], ret@coef[3]), lesDistr)  
   
